[![http://dnplab.net](https://img.shields.io/pypi/v/dnplab)](https://pypi.org/project/dnplab/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/dnplab)](https://www.python.org/downloads/)
[![Downloads](https://pepy.tech/badge/dnplab/month)](https://pepy.tech/project/dnplab)

[![DNPLab Logo](http://dnplab.net/_static/dnpLabLogo.png)](http://dnplab.net)
# DNPLab - Bringing the Power of Python to DNP-NMR Spectroscopy

DNPLab is a collaborative project created by:
- [Bridge12 Technologies, Inc.](http://www.bridge12.com/)
- [Han Lab UCSB](https://han.chem.ucsb.edu/)
- [Franck Lab Syracuse University](https://jmfrancklab.github.io/)

Authors:
Timothy Keller, Thomas Casey, Yanxian Lin, John Franck, Thorsten Maly, Songi Han


DNPLab is an object-oriented Open Source Python-based package for importing, processing, and analyzing data determined in a [Dynamic Nuclear Polarization (DNP)](https://www.bridge12.com/learn/dnp-spectroscopy/) experiment.

# Features

  - Import many different NMR data formats (Topspin, VnmrJ, Prospa, ...)
  - Create N-dimensional data objects
  - Easy processing of NMR data (apodization, zero-filling, Fourier transformations, alignment, ...)
  - Analyze data using the specific modules

# Installation

DNPLab can be easily installed via pip:

```console
pip install dnplab
```

# Documenation

Find the online documentation at: http://docs.dnplab.net

# Developement 

  - Clone the git repository from https://github.com/DNPLab/dnplab
